# coding: utf-8

# flake8: noqa
"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.2 (Build: 20250811)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


if __import__("typing").TYPE_CHECKING:
    # import models into model package
    from poodle_async_mini.models.core_course_get_contents_parameters_options_inner import CoreCourseGetContentsParametersOptionsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner import CoreCourseGetContentsResponseInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of_badgeextraattributes_inner import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner_rulevalue import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner_tags_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner
    from poodle_async_mini.models.core_enrol_get_users_courses_response_inner import CoreEnrolGetUsersCoursesResponseInner
    from poodle_async_mini.models.core_enrol_get_users_courses_response_inner_overviewfiles_inner import CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner
    from poodle_async_mini.models.core_group_get_course_groups_response_inner import CoreGroupGetCourseGroupsResponseInner
    from poodle_async_mini.models.core_webservice_get_site_info_response import CoreWebserviceGetSiteInfoResponse
    from poodle_async_mini.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
    from poodle_async_mini.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner
    from poodle_async_mini.models.gradereport_user_get_grade_items_response import GradereportUserGetGradeItemsResponse
    from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner import GradereportUserGetGradeItemsResponseUsergradesInner
    from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner_gradeitems_inner import GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner
    from poodle_async_mini.models.gradereport_user_get_grade_items_response_warnings_inner import GradereportUserGetGradeItemsResponseWarningsInner
    from poodle_async_mini.models.login_token200_response import LoginToken200Response
    from poodle_async_mini.models.mod_assign_get_assignments_response import ModAssignGetAssignmentsResponse
    from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner import ModAssignGetAssignmentsResponseCoursesInner
    from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner
    from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
    from poodle_async_mini.models.mod_assign_get_assignments_response_warnings_inner import ModAssignGetAssignmentsResponseWarningsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response import ModAssignGetSubmissionsResponse
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner import ModAssignGetSubmissionsResponseAssignmentsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_editorfields_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_fileareas_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner import ModAssignListParticipantsResponseInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_customfields_inner import ModAssignListParticipantsResponseInnerCustomfieldsInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_enrolledcourses_inner import ModAssignListParticipantsResponseInnerEnrolledcoursesInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_groups_inner import ModAssignListParticipantsResponseInnerGroupsInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_preferences_inner import ModAssignListParticipantsResponseInnerPreferencesInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_roles_inner import ModAssignListParticipantsResponseInnerRolesInner
    from poodle_async_mini.models.tool_mobile_get_public_config_response import ToolMobileGetPublicConfigResponse
    from poodle_async_mini.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            """# import models into model package
from poodle_async_mini.models.core_course_get_contents_parameters_options_inner import CoreCourseGetContentsParametersOptionsInner
from poodle_async_mini.models.core_course_get_contents_response_inner import CoreCourseGetContentsResponseInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of_badgeextraattributes_inner import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner_rulevalue import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner_tags_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner
from poodle_async_mini.models.core_enrol_get_users_courses_response_inner import CoreEnrolGetUsersCoursesResponseInner
from poodle_async_mini.models.core_enrol_get_users_courses_response_inner_overviewfiles_inner import CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner
from poodle_async_mini.models.core_group_get_course_groups_response_inner import CoreGroupGetCourseGroupsResponseInner
from poodle_async_mini.models.core_webservice_get_site_info_response import CoreWebserviceGetSiteInfoResponse
from poodle_async_mini.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
from poodle_async_mini.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner
from poodle_async_mini.models.gradereport_user_get_grade_items_response import GradereportUserGetGradeItemsResponse
from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner import GradereportUserGetGradeItemsResponseUsergradesInner
from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner_gradeitems_inner import GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner
from poodle_async_mini.models.gradereport_user_get_grade_items_response_warnings_inner import GradereportUserGetGradeItemsResponseWarningsInner
from poodle_async_mini.models.login_token200_response import LoginToken200Response
from poodle_async_mini.models.mod_assign_get_assignments_response import ModAssignGetAssignmentsResponse
from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner import ModAssignGetAssignmentsResponseCoursesInner
from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner
from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
from poodle_async_mini.models.mod_assign_get_assignments_response_warnings_inner import ModAssignGetAssignmentsResponseWarningsInner
from poodle_async_mini.models.mod_assign_get_submissions_response import ModAssignGetSubmissionsResponse
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner import ModAssignGetSubmissionsResponseAssignmentsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_editorfields_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_fileareas_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner import ModAssignListParticipantsResponseInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_customfields_inner import ModAssignListParticipantsResponseInnerCustomfieldsInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_enrolledcourses_inner import ModAssignListParticipantsResponseInnerEnrolledcoursesInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_groups_inner import ModAssignListParticipantsResponseInnerGroupsInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_preferences_inner import ModAssignListParticipantsResponseInnerPreferencesInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_roles_inner import ModAssignListParticipantsResponseInnerRolesInner
from poodle_async_mini.models.tool_mobile_get_public_config_response import ToolMobileGetPublicConfigResponse
from poodle_async_mini.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner

""",
            name=__name__,
            doc=__doc__,
        )
    )



# coding: utf-8

# flake8: noqa

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.2 (Build: 20250811)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "5.0.2.post2"

# Define package exports
__all__ = [
    "DefaultApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "settings",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "CoreCourseGetContentsParametersOptionsInner",
    "CoreCourseGetContentsResponseInner",
    "CoreCourseGetContentsResponseInnerModulesInner",
    "CoreCourseGetContentsResponseInnerModulesInnerActivitybadge",
    "CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf",
    "CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner",
    "CoreCourseGetContentsResponseInnerModulesInnerCompletiondata",
    "CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner",
    "CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue",
    "CoreCourseGetContentsResponseInnerModulesInnerContentsInner",
    "CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner",
    "CoreCourseGetContentsResponseInnerModulesInnerContentsinfo",
    "CoreCourseGetContentsResponseInnerModulesInnerDatesInner",
    "CoreEnrolGetUsersCoursesResponseInner",
    "CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner",
    "CoreGroupGetCourseGroupsResponseInner",
    "CoreWebserviceGetSiteInfoResponse",
    "CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner",
    "CoreWebserviceGetSiteInfoResponseFunctionsInner",
    "GradereportUserGetGradeItemsResponse",
    "GradereportUserGetGradeItemsResponseUsergradesInner",
    "GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner",
    "GradereportUserGetGradeItemsResponseWarningsInner",
    "LoginToken200Response",
    "ModAssignGetAssignmentsResponse",
    "ModAssignGetAssignmentsResponseCoursesInner",
    "ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner",
    "ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner",
    "ModAssignGetAssignmentsResponseWarningsInner",
    "ModAssignGetSubmissionsResponse",
    "ModAssignGetSubmissionsResponseAssignmentsInner",
    "ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner",
    "ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner",
    "ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner",
    "ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner",
    "ModAssignListParticipantsResponseInner",
    "ModAssignListParticipantsResponseInnerCustomfieldsInner",
    "ModAssignListParticipantsResponseInnerEnrolledcoursesInner",
    "ModAssignListParticipantsResponseInnerGroupsInner",
    "ModAssignListParticipantsResponseInnerPreferencesInner",
    "ModAssignListParticipantsResponseInnerRolesInner",
    "ToolMobileGetPublicConfigResponse",
    "ToolMobileGetPublicConfigResponseIdentityprovidersInner",
]

if __import__("typing").TYPE_CHECKING:
    # import apis into sdk package
    from poodle_async_mini.api.default_api import DefaultApi as DefaultApi
    
    # import ApiClient
    from poodle_async_mini.api_response import ApiResponse as ApiResponse
    from poodle_async_mini.api_client import ApiClient as ApiClient
    from poodle_async_mini.configuration import Configuration as Configuration
    from poodle_async_mini.configuration import settings as settings
    from poodle_async_mini.exceptions import OpenApiException as OpenApiException
    from poodle_async_mini.exceptions import ApiTypeError as ApiTypeError
    from poodle_async_mini.exceptions import ApiValueError as ApiValueError
    from poodle_async_mini.exceptions import ApiKeyError as ApiKeyError
    from poodle_async_mini.exceptions import ApiAttributeError as ApiAttributeError
    from poodle_async_mini.exceptions import ApiException as ApiException
    
    # import models into sdk package
    from poodle_async_mini.models.core_course_get_contents_parameters_options_inner import CoreCourseGetContentsParametersOptionsInner as CoreCourseGetContentsParametersOptionsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner import CoreCourseGetContentsResponseInner as CoreCourseGetContentsResponseInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner as CoreCourseGetContentsResponseInnerModulesInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge as CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf as CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of_badgeextraattributes_inner import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner as CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata as CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner as CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner_rulevalue import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue as CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner as CoreCourseGetContentsResponseInnerModulesInnerContentsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner_tags_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner as CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo as CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
    from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner as CoreCourseGetContentsResponseInnerModulesInnerDatesInner
    from poodle_async_mini.models.core_enrol_get_users_courses_response_inner import CoreEnrolGetUsersCoursesResponseInner as CoreEnrolGetUsersCoursesResponseInner
    from poodle_async_mini.models.core_enrol_get_users_courses_response_inner_overviewfiles_inner import CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner as CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner
    from poodle_async_mini.models.core_group_get_course_groups_response_inner import CoreGroupGetCourseGroupsResponseInner as CoreGroupGetCourseGroupsResponseInner
    from poodle_async_mini.models.core_webservice_get_site_info_response import CoreWebserviceGetSiteInfoResponse as CoreWebserviceGetSiteInfoResponse
    from poodle_async_mini.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner as CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
    from poodle_async_mini.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner as CoreWebserviceGetSiteInfoResponseFunctionsInner
    from poodle_async_mini.models.gradereport_user_get_grade_items_response import GradereportUserGetGradeItemsResponse as GradereportUserGetGradeItemsResponse
    from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner import GradereportUserGetGradeItemsResponseUsergradesInner as GradereportUserGetGradeItemsResponseUsergradesInner
    from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner_gradeitems_inner import GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner as GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner
    from poodle_async_mini.models.gradereport_user_get_grade_items_response_warnings_inner import GradereportUserGetGradeItemsResponseWarningsInner as GradereportUserGetGradeItemsResponseWarningsInner
    from poodle_async_mini.models.login_token200_response import LoginToken200Response as LoginToken200Response
    from poodle_async_mini.models.mod_assign_get_assignments_response import ModAssignGetAssignmentsResponse as ModAssignGetAssignmentsResponse
    from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner import ModAssignGetAssignmentsResponseCoursesInner as ModAssignGetAssignmentsResponseCoursesInner
    from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner as ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner
    from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner as ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
    from poodle_async_mini.models.mod_assign_get_assignments_response_warnings_inner import ModAssignGetAssignmentsResponseWarningsInner as ModAssignGetAssignmentsResponseWarningsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response import ModAssignGetSubmissionsResponse as ModAssignGetSubmissionsResponse
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner import ModAssignGetSubmissionsResponseAssignmentsInner as ModAssignGetSubmissionsResponseAssignmentsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_editorfields_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner
    from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_fileareas_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner import ModAssignListParticipantsResponseInner as ModAssignListParticipantsResponseInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_customfields_inner import ModAssignListParticipantsResponseInnerCustomfieldsInner as ModAssignListParticipantsResponseInnerCustomfieldsInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_enrolledcourses_inner import ModAssignListParticipantsResponseInnerEnrolledcoursesInner as ModAssignListParticipantsResponseInnerEnrolledcoursesInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_groups_inner import ModAssignListParticipantsResponseInnerGroupsInner as ModAssignListParticipantsResponseInnerGroupsInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_preferences_inner import ModAssignListParticipantsResponseInnerPreferencesInner as ModAssignListParticipantsResponseInnerPreferencesInner
    from poodle_async_mini.models.mod_assign_list_participants_response_inner_roles_inner import ModAssignListParticipantsResponseInnerRolesInner as ModAssignListParticipantsResponseInnerRolesInner
    from poodle_async_mini.models.tool_mobile_get_public_config_response import ToolMobileGetPublicConfigResponse as ToolMobileGetPublicConfigResponse
    from poodle_async_mini.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner as ToolMobileGetPublicConfigResponseIdentityprovidersInner
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            ("__version__", __version__),
            ("__all__", __all__),
            """# import apis into sdk package
from poodle_async_mini.api.default_api import DefaultApi as DefaultApi

# import ApiClient
from poodle_async_mini.api_response import ApiResponse as ApiResponse
from poodle_async_mini.api_client import ApiClient as ApiClient
from poodle_async_mini.configuration import Configuration as Configuration
from poodle_async_mini.configuration import settings as settings
from poodle_async_mini.exceptions import OpenApiException as OpenApiException
from poodle_async_mini.exceptions import ApiTypeError as ApiTypeError
from poodle_async_mini.exceptions import ApiValueError as ApiValueError
from poodle_async_mini.exceptions import ApiKeyError as ApiKeyError
from poodle_async_mini.exceptions import ApiAttributeError as ApiAttributeError
from poodle_async_mini.exceptions import ApiException as ApiException

# import models into sdk package
from poodle_async_mini.models.core_course_get_contents_parameters_options_inner import CoreCourseGetContentsParametersOptionsInner as CoreCourseGetContentsParametersOptionsInner
from poodle_async_mini.models.core_course_get_contents_response_inner import CoreCourseGetContentsResponseInner as CoreCourseGetContentsResponseInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner as CoreCourseGetContentsResponseInnerModulesInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge as CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf as CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of_badgeextraattributes_inner import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner as CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata as CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner as CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner_rulevalue import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue as CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner as CoreCourseGetContentsResponseInnerModulesInnerContentsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner_tags_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner as CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo as CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner as CoreCourseGetContentsResponseInnerModulesInnerDatesInner
from poodle_async_mini.models.core_enrol_get_users_courses_response_inner import CoreEnrolGetUsersCoursesResponseInner as CoreEnrolGetUsersCoursesResponseInner
from poodle_async_mini.models.core_enrol_get_users_courses_response_inner_overviewfiles_inner import CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner as CoreEnrolGetUsersCoursesResponseInnerOverviewfilesInner
from poodle_async_mini.models.core_group_get_course_groups_response_inner import CoreGroupGetCourseGroupsResponseInner as CoreGroupGetCourseGroupsResponseInner
from poodle_async_mini.models.core_webservice_get_site_info_response import CoreWebserviceGetSiteInfoResponse as CoreWebserviceGetSiteInfoResponse
from poodle_async_mini.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner as CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
from poodle_async_mini.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner as CoreWebserviceGetSiteInfoResponseFunctionsInner
from poodle_async_mini.models.gradereport_user_get_grade_items_response import GradereportUserGetGradeItemsResponse as GradereportUserGetGradeItemsResponse
from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner import GradereportUserGetGradeItemsResponseUsergradesInner as GradereportUserGetGradeItemsResponseUsergradesInner
from poodle_async_mini.models.gradereport_user_get_grade_items_response_usergrades_inner_gradeitems_inner import GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner as GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner
from poodle_async_mini.models.gradereport_user_get_grade_items_response_warnings_inner import GradereportUserGetGradeItemsResponseWarningsInner as GradereportUserGetGradeItemsResponseWarningsInner
from poodle_async_mini.models.login_token200_response import LoginToken200Response as LoginToken200Response
from poodle_async_mini.models.mod_assign_get_assignments_response import ModAssignGetAssignmentsResponse as ModAssignGetAssignmentsResponse
from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner import ModAssignGetAssignmentsResponseCoursesInner as ModAssignGetAssignmentsResponseCoursesInner
from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner as ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner
from poodle_async_mini.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner as ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
from poodle_async_mini.models.mod_assign_get_assignments_response_warnings_inner import ModAssignGetAssignmentsResponseWarningsInner as ModAssignGetAssignmentsResponseWarningsInner
from poodle_async_mini.models.mod_assign_get_submissions_response import ModAssignGetSubmissionsResponse as ModAssignGetSubmissionsResponse
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner import ModAssignGetSubmissionsResponseAssignmentsInner as ModAssignGetSubmissionsResponseAssignmentsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_editorfields_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerEditorfieldsInner
from poodle_async_mini.models.mod_assign_get_submissions_response_assignments_inner_submissions_inner_plugins_inner_fileareas_inner import ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner as ModAssignGetSubmissionsResponseAssignmentsInnerSubmissionsInnerPluginsInnerFileareasInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner import ModAssignListParticipantsResponseInner as ModAssignListParticipantsResponseInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_customfields_inner import ModAssignListParticipantsResponseInnerCustomfieldsInner as ModAssignListParticipantsResponseInnerCustomfieldsInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_enrolledcourses_inner import ModAssignListParticipantsResponseInnerEnrolledcoursesInner as ModAssignListParticipantsResponseInnerEnrolledcoursesInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_groups_inner import ModAssignListParticipantsResponseInnerGroupsInner as ModAssignListParticipantsResponseInnerGroupsInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_preferences_inner import ModAssignListParticipantsResponseInnerPreferencesInner as ModAssignListParticipantsResponseInnerPreferencesInner
from poodle_async_mini.models.mod_assign_list_participants_response_inner_roles_inner import ModAssignListParticipantsResponseInnerRolesInner as ModAssignListParticipantsResponseInnerRolesInner
from poodle_async_mini.models.tool_mobile_get_public_config_response import ToolMobileGetPublicConfigResponse as ToolMobileGetPublicConfigResponse
from poodle_async_mini.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner as ToolMobileGetPublicConfigResponseIdentityprovidersInner

""",
            name=__name__,
            doc=__doc__,
        )
    )



# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.2 (Build: 20250811)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_mini.configuration import settings

class CoreCourseGetContentsResponseInnerModulesInner(BaseModel):
    """
    CoreCourseGetContentsResponseInnerModulesInner
    """ # noqa: E501
    activitybadge: Optional[CoreCourseGetContentsResponseInnerModulesInnerActivitybadge] = None
    afterlink: Optional[StrictStr] = Field(default=None, description="After link info to be displayed.")
    availability: Optional[StrictStr] = Field(default=None, description="module availability settings")
    availabilityinfo: Optional[StrictStr] = Field(default=None, description="Availability information.")
    branded: Optional[StrictBool] = Field(default=None, description="Whether the module is branded or not")
    completion: Optional[StrictInt] = Field(default=None, description="Type of completion tracking:                                         0 means none, 1 manual, 2 automatic.")
    completiondata: Optional[CoreCourseGetContentsResponseInnerModulesInnerCompletiondata] = None
    contents: Optional[List[CoreCourseGetContentsResponseInnerModulesInnerContentsInner]] = Field(default=None, description="Course contents")
    contentsinfo: Optional[CoreCourseGetContentsResponseInnerModulesInnerContentsinfo] = None
    contextid: Optional[StrictInt] = Field(default=None, description="Activity context id.")
    customdata: Optional[StrictStr] = Field(default=None, description="Custom data (JSON encoded).")
    dates: Optional[List[CoreCourseGetContentsResponseInnerModulesInnerDatesInner]] = Field(default=None, description="Course dates")
    description: Optional[StrictStr] = Field(default=None, description="activity description")
    downloadcontent: Optional[StrictInt] = Field(default=None, description="The download content value")
    groupmode: Optional[StrictInt] = Field(default=None, description="Group mode value")
    id: Optional[StrictInt] = Field(description="activity id")
    indent: Optional[StrictInt] = Field(description="number of identation in the site")
    instance: Optional[StrictInt] = Field(default=None, description="instance id")
    modicon: Optional[StrictStr] = Field(description="activity icon url")
    modname: Optional[StrictStr] = Field(description="activity module type")
    modplural: Optional[StrictStr] = Field(description="activity module plural name")
    name: Optional[StrictStr] = Field(description="activity module name")
    noviewlink: Optional[StrictBool] = Field(default=None, description="Whether the module has no view page")
    onclick: Optional[StrictStr] = Field(default=None, description="Onclick action.")
    purpose: Optional[StrictStr] = Field(description="the module purpose")
    url: Optional[StrictStr] = Field(default=None, description="activity url")
    uservisible: Optional[StrictBool] = Field(default=None, description="Is the module visible for the user?")
    visible: Optional[StrictInt] = Field(default=None, description="is the module visible")
    visibleoncoursepage: Optional[StrictInt] = Field(default=None, description="is the module visible on course page")
    __properties: ClassVar[List[str]] = ["activitybadge", "afterlink", "availability", "availabilityinfo", "branded", "completion", "completiondata", "contents", "contentsinfo", "contextid", "customdata", "dates", "description", "downloadcontent", "groupmode", "id", "indent", "instance", "modicon", "modname", "modplural", "name", "noviewlink", "onclick", "purpose", "url", "uservisible", "visible", "visibleoncoursepage"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCourseGetContentsResponseInnerModulesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of activitybadge
        if self.activitybadge:
            _dict['activitybadge'] = self.activitybadge.to_dict()
        # override the default output from pydantic by calling `to_dict()` of completiondata
        if self.completiondata:
            _dict['completiondata'] = self.completiondata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in contents (list)
        _items = []
        if self.contents:
            for _item_contents in self.contents:
                if _item_contents:
                    _items.append(_item_contents.to_dict())
            _dict['contents'] = _items
        # override the default output from pydantic by calling `to_dict()` of contentsinfo
        if self.contentsinfo:
            _dict['contentsinfo'] = self.contentsinfo.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in dates (list)
        _items = []
        if self.dates:
            for _item_dates in self.dates:
                if _item_dates:
                    _items.append(_item_dates.to_dict())
            _dict['dates'] = _items
        # set to None if afterlink (nullable) is None
        # and model_fields_set contains the field
        if self.afterlink is None and "afterlink" in self.model_fields_set:
            _dict['afterlink'] = None

        # set to None if availability (nullable) is None
        # and model_fields_set contains the field
        if self.availability is None and "availability" in self.model_fields_set:
            _dict['availability'] = None

        # set to None if availabilityinfo (nullable) is None
        # and model_fields_set contains the field
        if self.availabilityinfo is None and "availabilityinfo" in self.model_fields_set:
            _dict['availabilityinfo'] = None

        # set to None if branded (nullable) is None
        # and model_fields_set contains the field
        if self.branded is None and "branded" in self.model_fields_set:
            _dict['branded'] = None

        # set to None if completion (nullable) is None
        # and model_fields_set contains the field
        if self.completion is None and "completion" in self.model_fields_set:
            _dict['completion'] = None

        # set to None if contextid (nullable) is None
        # and model_fields_set contains the field
        if self.contextid is None and "contextid" in self.model_fields_set:
            _dict['contextid'] = None

        # set to None if customdata (nullable) is None
        # and model_fields_set contains the field
        if self.customdata is None and "customdata" in self.model_fields_set:
            _dict['customdata'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if downloadcontent (nullable) is None
        # and model_fields_set contains the field
        if self.downloadcontent is None and "downloadcontent" in self.model_fields_set:
            _dict['downloadcontent'] = None

        # set to None if groupmode (nullable) is None
        # and model_fields_set contains the field
        if self.groupmode is None and "groupmode" in self.model_fields_set:
            _dict['groupmode'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if indent (nullable) is None
        # and model_fields_set contains the field
        if self.indent is None and "indent" in self.model_fields_set:
            _dict['indent'] = None

        # set to None if instance (nullable) is None
        # and model_fields_set contains the field
        if self.instance is None and "instance" in self.model_fields_set:
            _dict['instance'] = None

        # set to None if modicon (nullable) is None
        # and model_fields_set contains the field
        if self.modicon is None and "modicon" in self.model_fields_set:
            _dict['modicon'] = None

        # set to None if modname (nullable) is None
        # and model_fields_set contains the field
        if self.modname is None and "modname" in self.model_fields_set:
            _dict['modname'] = None

        # set to None if modplural (nullable) is None
        # and model_fields_set contains the field
        if self.modplural is None and "modplural" in self.model_fields_set:
            _dict['modplural'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if noviewlink (nullable) is None
        # and model_fields_set contains the field
        if self.noviewlink is None and "noviewlink" in self.model_fields_set:
            _dict['noviewlink'] = None

        # set to None if onclick (nullable) is None
        # and model_fields_set contains the field
        if self.onclick is None and "onclick" in self.model_fields_set:
            _dict['onclick'] = None

        # set to None if purpose (nullable) is None
        # and model_fields_set contains the field
        if self.purpose is None and "purpose" in self.model_fields_set:
            _dict['purpose'] = None

        # set to None if url (nullable) is None
        # and model_fields_set contains the field
        if self.url is None and "url" in self.model_fields_set:
            _dict['url'] = None

        # set to None if uservisible (nullable) is None
        # and model_fields_set contains the field
        if self.uservisible is None and "uservisible" in self.model_fields_set:
            _dict['uservisible'] = None

        # set to None if visible (nullable) is None
        # and model_fields_set contains the field
        if self.visible is None and "visible" in self.model_fields_set:
            _dict['visible'] = None

        # set to None if visibleoncoursepage (nullable) is None
        # and model_fields_set contains the field
        if self.visibleoncoursepage is None and "visibleoncoursepage" in self.model_fields_set:
            _dict['visibleoncoursepage'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCourseGetContentsResponseInnerModulesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCourseGetContentsResponseInnerModulesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "activitybadge": CoreCourseGetContentsResponseInnerModulesInnerActivitybadge.from_dict(obj["activitybadge"]) if obj.get("activitybadge") is not None else None,
            "afterlink": obj.get("afterlink"),
            "availability": obj.get("availability"),
            "availabilityinfo": obj.get("availabilityinfo"),
            "branded": obj.get("branded"),
            "completion": obj.get("completion"),
            "completiondata": CoreCourseGetContentsResponseInnerModulesInnerCompletiondata.from_dict(obj["completiondata"]) if obj.get("completiondata") is not None else None,
            "contents": [CoreCourseGetContentsResponseInnerModulesInnerContentsInner.from_dict(_item) for _item in obj["contents"]] if obj.get("contents") is not None else None,
            "contentsinfo": CoreCourseGetContentsResponseInnerModulesInnerContentsinfo.from_dict(obj["contentsinfo"]) if obj.get("contentsinfo") is not None else None,
            "contextid": obj.get("contextid"),
            "customdata": obj.get("customdata"),
            "dates": [CoreCourseGetContentsResponseInnerModulesInnerDatesInner.from_dict(_item) for _item in obj["dates"]] if obj.get("dates") is not None else None,
            "description": obj.get("description"),
            "downloadcontent": obj.get("downloadcontent"),
            "groupmode": obj.get("groupmode"),
            "id": obj.get("id"),
            "indent": obj.get("indent"),
            "instance": obj.get("instance"),
            "modicon": obj.get("modicon"),
            "modname": obj.get("modname"),
            "modplural": obj.get("modplural"),
            "name": obj.get("name"),
            "noviewlink": obj.get("noviewlink"),
            "onclick": obj.get("onclick"),
            "purpose": obj.get("purpose"),
            "url": obj.get("url"),
            "uservisible": obj.get("uservisible"),
            "visible": obj.get("visible"),
            "visibleoncoursepage": obj.get("visibleoncoursepage")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# flake8: noqa

if __import__("typing").TYPE_CHECKING:
    # import apis into api package
    from poodle_async_mini.api.default_api import DefaultApi
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            """# import apis into api package
from poodle_async_mini.api.default_api import DefaultApi

""",
            name=__name__,
            doc=__doc__,
        )
    )



# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.2 (Build: 20250811)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_mini.models.gradereport_user_get_grade_items_response_warnings_inner import GradereportUserGetGradeItemsResponseWarningsInner
from poodle_async_mini.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_mini.configuration import settings

class ToolMobileGetPublicConfigResponse(BaseModel):
    """
    ToolMobileGetPublicConfigResponse
    """ # noqa: E501
    agedigitalconsentverification: Optional[StrictBool] = Field(default=None, description="Whether age digital consent verification                     is enabled.")
    authinstructions: Optional[StrictStr] = Field(description="Authentication instructions.")
    authloginviaemail: Optional[StrictInt] = Field(description="Whether log in via email is enabled.")
    authnoneenabled: Optional[StrictInt] = Field(description="Whether auth none is enabled.")
    autolang: Optional[StrictInt] = Field(default=None, description="Whether to detect default language                     from browser setting.")
    compactlogourl: Optional[StrictStr] = Field(default=None, description="The site compact logo URL")
    country: Optional[StrictStr] = Field(default=None, description="Default site country")
    enablemobilewebservice: Optional[StrictInt] = Field(description="Whether the Mobile service is enabled.")
    enablewebservices: Optional[StrictInt] = Field(description="Whether Web Services are enabled.")
    forgottenpasswordurl: Optional[StrictStr] = Field(description="Forgotten password URL.")
    guestlogin: Optional[StrictInt] = Field(description="Whether guest login is enabled.")
    httpswwwroot: Optional[StrictStr] = Field(description="Site https URL (if httpslogin is enabled).")
    identityproviders: Optional[List[ToolMobileGetPublicConfigResponseIdentityprovidersInner]] = Field(default=None, description="Identity providers")
    lang: Optional[StrictStr] = Field(default=None, description="Default language for the site.")
    langlist: Optional[StrictStr] = Field(default=None, description="Languages on language menu.")
    langmenu: Optional[StrictInt] = Field(default=None, description="Whether the language menu should be displayed.")
    launchurl: Optional[StrictStr] = Field(default=None, description="SSO login launch URL.")
    locale: Optional[StrictStr] = Field(default=None, description="Sitewide locale.")
    logourl: Optional[StrictStr] = Field(default=None, description="The site logo URL")
    maintenanceenabled: Optional[StrictInt] = Field(description="Whether site maintenance is enabled.")
    maintenancemessage: Optional[StrictStr] = Field(description="Maintenance message.")
    mobilecssurl: Optional[StrictStr] = Field(default=None, description="Mobile custom CSS theme")
    registerauth: Optional[StrictStr] = Field(description="Authentication method for user registration.")
    rememberusername: Optional[StrictInt] = Field(description="Values: 0 for No, 1 for Yes, 2 for optional.")
    showloginform: Optional[StrictInt] = Field(description="Display default login form.")
    sitename: Optional[StrictStr] = Field(description="Site name.")
    supportavailability: Optional[StrictInt] = Field(default=None, description="Determines who has access to contact site support.")
    supportemail: Optional[StrictStr] = Field(default=None, description="Site support contact email                     (only if age verification is enabled).")
    supportname: Optional[StrictStr] = Field(default=None, description="Site support contact name                     (only if age verification is enabled).")
    supportpage: Optional[StrictStr] = Field(default=None, description="Site support page link.")
    tool_mobile_androidappid: Optional[StrictStr] = Field(default=None, description="Android app's unique identifier.")
    tool_mobile_disabledfeatures: Optional[StrictStr] = Field(default=None, description="Disabled features in the app")
    tool_mobile_iosappid: Optional[StrictStr] = Field(default=None, description="iOS app's unique identifier.")
    tool_mobile_minimumversion: Optional[StrictStr] = Field(default=None, description="Minimum required version to access.")
    tool_mobile_qrcodetype: Optional[StrictInt] = Field(default=None, description="QR login configuration.")
    tool_mobile_setuplink: Optional[StrictStr] = Field(default=None, description="App download page.")
    typeoflogin: Optional[StrictInt] = Field(description="The type of login. 1 for app, 2 for browser, 3 for embedded.")
    warnings: Optional[List[GradereportUserGetGradeItemsResponseWarningsInner]] = Field(default=None, description="list of warnings")
    wwwroot: Optional[StrictStr] = Field(description="Site URL.")
    __properties: ClassVar[List[str]] = ["agedigitalconsentverification", "authinstructions", "authloginviaemail", "authnoneenabled", "autolang", "compactlogourl", "country", "enablemobilewebservice", "enablewebservices", "forgottenpasswordurl", "guestlogin", "httpswwwroot", "identityproviders", "lang", "langlist", "langmenu", "launchurl", "locale", "logourl", "maintenanceenabled", "maintenancemessage", "mobilecssurl", "registerauth", "rememberusername", "showloginform", "sitename", "supportavailability", "supportemail", "supportname", "supportpage", "tool_mobile_androidappid", "tool_mobile_disabledfeatures", "tool_mobile_iosappid", "tool_mobile_minimumversion", "tool_mobile_qrcodetype", "tool_mobile_setuplink", "typeoflogin", "warnings", "wwwroot"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ToolMobileGetPublicConfigResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in identityproviders (list)
        _items = []
        if self.identityproviders:
            for _item_identityproviders in self.identityproviders:
                if _item_identityproviders:
                    _items.append(_item_identityproviders.to_dict())
            _dict['identityproviders'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in warnings (list)
        _items = []
        if self.warnings:
            for _item_warnings in self.warnings:
                if _item_warnings:
                    _items.append(_item_warnings.to_dict())
            _dict['warnings'] = _items
        # set to None if agedigitalconsentverification (nullable) is None
        # and model_fields_set contains the field
        if self.agedigitalconsentverification is None and "agedigitalconsentverification" in self.model_fields_set:
            _dict['agedigitalconsentverification'] = None

        # set to None if authinstructions (nullable) is None
        # and model_fields_set contains the field
        if self.authinstructions is None and "authinstructions" in self.model_fields_set:
            _dict['authinstructions'] = None

        # set to None if authloginviaemail (nullable) is None
        # and model_fields_set contains the field
        if self.authloginviaemail is None and "authloginviaemail" in self.model_fields_set:
            _dict['authloginviaemail'] = None

        # set to None if authnoneenabled (nullable) is None
        # and model_fields_set contains the field
        if self.authnoneenabled is None and "authnoneenabled" in self.model_fields_set:
            _dict['authnoneenabled'] = None

        # set to None if autolang (nullable) is None
        # and model_fields_set contains the field
        if self.autolang is None and "autolang" in self.model_fields_set:
            _dict['autolang'] = None

        # set to None if compactlogourl (nullable) is None
        # and model_fields_set contains the field
        if self.compactlogourl is None and "compactlogourl" in self.model_fields_set:
            _dict['compactlogourl'] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict['country'] = None

        # set to None if enablemobilewebservice (nullable) is None
        # and model_fields_set contains the field
        if self.enablemobilewebservice is None and "enablemobilewebservice" in self.model_fields_set:
            _dict['enablemobilewebservice'] = None

        # set to None if enablewebservices (nullable) is None
        # and model_fields_set contains the field
        if self.enablewebservices is None and "enablewebservices" in self.model_fields_set:
            _dict['enablewebservices'] = None

        # set to None if forgottenpasswordurl (nullable) is None
        # and model_fields_set contains the field
        if self.forgottenpasswordurl is None and "forgottenpasswordurl" in self.model_fields_set:
            _dict['forgottenpasswordurl'] = None

        # set to None if guestlogin (nullable) is None
        # and model_fields_set contains the field
        if self.guestlogin is None and "guestlogin" in self.model_fields_set:
            _dict['guestlogin'] = None

        # set to None if httpswwwroot (nullable) is None
        # and model_fields_set contains the field
        if self.httpswwwroot is None and "httpswwwroot" in self.model_fields_set:
            _dict['httpswwwroot'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if langlist (nullable) is None
        # and model_fields_set contains the field
        if self.langlist is None and "langlist" in self.model_fields_set:
            _dict['langlist'] = None

        # set to None if langmenu (nullable) is None
        # and model_fields_set contains the field
        if self.langmenu is None and "langmenu" in self.model_fields_set:
            _dict['langmenu'] = None

        # set to None if launchurl (nullable) is None
        # and model_fields_set contains the field
        if self.launchurl is None and "launchurl" in self.model_fields_set:
            _dict['launchurl'] = None

        # set to None if locale (nullable) is None
        # and model_fields_set contains the field
        if self.locale is None and "locale" in self.model_fields_set:
            _dict['locale'] = None

        # set to None if logourl (nullable) is None
        # and model_fields_set contains the field
        if self.logourl is None and "logourl" in self.model_fields_set:
            _dict['logourl'] = None

        # set to None if maintenanceenabled (nullable) is None
        # and model_fields_set contains the field
        if self.maintenanceenabled is None and "maintenanceenabled" in self.model_fields_set:
            _dict['maintenanceenabled'] = None

        # set to None if maintenancemessage (nullable) is None
        # and model_fields_set contains the field
        if self.maintenancemessage is None and "maintenancemessage" in self.model_fields_set:
            _dict['maintenancemessage'] = None

        # set to None if mobilecssurl (nullable) is None
        # and model_fields_set contains the field
        if self.mobilecssurl is None and "mobilecssurl" in self.model_fields_set:
            _dict['mobilecssurl'] = None

        # set to None if registerauth (nullable) is None
        # and model_fields_set contains the field
        if self.registerauth is None and "registerauth" in self.model_fields_set:
            _dict['registerauth'] = None

        # set to None if rememberusername (nullable) is None
        # and model_fields_set contains the field
        if self.rememberusername is None and "rememberusername" in self.model_fields_set:
            _dict['rememberusername'] = None

        # set to None if showloginform (nullable) is None
        # and model_fields_set contains the field
        if self.showloginform is None and "showloginform" in self.model_fields_set:
            _dict['showloginform'] = None

        # set to None if sitename (nullable) is None
        # and model_fields_set contains the field
        if self.sitename is None and "sitename" in self.model_fields_set:
            _dict['sitename'] = None

        # set to None if supportavailability (nullable) is None
        # and model_fields_set contains the field
        if self.supportavailability is None and "supportavailability" in self.model_fields_set:
            _dict['supportavailability'] = None

        # set to None if supportemail (nullable) is None
        # and model_fields_set contains the field
        if self.supportemail is None and "supportemail" in self.model_fields_set:
            _dict['supportemail'] = None

        # set to None if supportname (nullable) is None
        # and model_fields_set contains the field
        if self.supportname is None and "supportname" in self.model_fields_set:
            _dict['supportname'] = None

        # set to None if supportpage (nullable) is None
        # and model_fields_set contains the field
        if self.supportpage is None and "supportpage" in self.model_fields_set:
            _dict['supportpage'] = None

        # set to None if tool_mobile_androidappid (nullable) is None
        # and model_fields_set contains the field
        if self.tool_mobile_androidappid is None and "tool_mobile_androidappid" in self.model_fields_set:
            _dict['tool_mobile_androidappid'] = None

        # set to None if tool_mobile_disabledfeatures (nullable) is None
        # and model_fields_set contains the field
        if self.tool_mobile_disabledfeatures is None and "tool_mobile_disabledfeatures" in self.model_fields_set:
            _dict['tool_mobile_disabledfeatures'] = None

        # set to None if tool_mobile_iosappid (nullable) is None
        # and model_fields_set contains the field
        if self.tool_mobile_iosappid is None and "tool_mobile_iosappid" in self.model_fields_set:
            _dict['tool_mobile_iosappid'] = None

        # set to None if tool_mobile_minimumversion (nullable) is None
        # and model_fields_set contains the field
        if self.tool_mobile_minimumversion is None and "tool_mobile_minimumversion" in self.model_fields_set:
            _dict['tool_mobile_minimumversion'] = None

        # set to None if tool_mobile_qrcodetype (nullable) is None
        # and model_fields_set contains the field
        if self.tool_mobile_qrcodetype is None and "tool_mobile_qrcodetype" in self.model_fields_set:
            _dict['tool_mobile_qrcodetype'] = None

        # set to None if tool_mobile_setuplink (nullable) is None
        # and model_fields_set contains the field
        if self.tool_mobile_setuplink is None and "tool_mobile_setuplink" in self.model_fields_set:
            _dict['tool_mobile_setuplink'] = None

        # set to None if typeoflogin (nullable) is None
        # and model_fields_set contains the field
        if self.typeoflogin is None and "typeoflogin" in self.model_fields_set:
            _dict['typeoflogin'] = None

        # set to None if wwwroot (nullable) is None
        # and model_fields_set contains the field
        if self.wwwroot is None and "wwwroot" in self.model_fields_set:
            _dict['wwwroot'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ToolMobileGetPublicConfigResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ToolMobileGetPublicConfigResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "agedigitalconsentverification": obj.get("agedigitalconsentverification"),
            "authinstructions": obj.get("authinstructions"),
            "authloginviaemail": obj.get("authloginviaemail"),
            "authnoneenabled": obj.get("authnoneenabled"),
            "autolang": obj.get("autolang"),
            "compactlogourl": obj.get("compactlogourl"),
            "country": obj.get("country"),
            "enablemobilewebservice": obj.get("enablemobilewebservice"),
            "enablewebservices": obj.get("enablewebservices"),
            "forgottenpasswordurl": obj.get("forgottenpasswordurl"),
            "guestlogin": obj.get("guestlogin"),
            "httpswwwroot": obj.get("httpswwwroot"),
            "identityproviders": [ToolMobileGetPublicConfigResponseIdentityprovidersInner.from_dict(_item) for _item in obj["identityproviders"]] if obj.get("identityproviders") is not None else None,
            "lang": obj.get("lang"),
            "langlist": obj.get("langlist"),
            "langmenu": obj.get("langmenu"),
            "launchurl": obj.get("launchurl"),
            "locale": obj.get("locale"),
            "logourl": obj.get("logourl"),
            "maintenanceenabled": obj.get("maintenanceenabled"),
            "maintenancemessage": obj.get("maintenancemessage"),
            "mobilecssurl": obj.get("mobilecssurl"),
            "registerauth": obj.get("registerauth"),
            "rememberusername": obj.get("rememberusername"),
            "showloginform": obj.get("showloginform"),
            "sitename": obj.get("sitename"),
            "supportavailability": obj.get("supportavailability"),
            "supportemail": obj.get("supportemail"),
            "supportname": obj.get("supportname"),
            "supportpage": obj.get("supportpage"),
            "tool_mobile_androidappid": obj.get("tool_mobile_androidappid"),
            "tool_mobile_disabledfeatures": obj.get("tool_mobile_disabledfeatures"),
            "tool_mobile_iosappid": obj.get("tool_mobile_iosappid"),
            "tool_mobile_minimumversion": obj.get("tool_mobile_minimumversion"),
            "tool_mobile_qrcodetype": obj.get("tool_mobile_qrcodetype"),
            "tool_mobile_setuplink": obj.get("tool_mobile_setuplink"),
            "typeoflogin": obj.get("typeoflogin"),
            "warnings": [GradereportUserGetGradeItemsResponseWarningsInner.from_dict(_item) for _item in obj["warnings"]] if obj.get("warnings") is not None else None,
            "wwwroot": obj.get("wwwroot")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.2 (Build: 20250811)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_mini.configuration import settings

class CoreCourseGetContentsParametersOptionsInner(BaseModel):
    """
    CoreCourseGetContentsParametersOptionsInner
    """ # noqa: E501
    name: Optional[StrictStr] = Field(description="The expected keys (value format) are:                                                 excludemodules (bool) Do not return modules, return only the sections structure                                                 excludecontents (bool) Do not return module contents (i.e: files inside a resource)                                                 includestealthmodules (bool) Return stealth modules for students in a special                                                     section (with id -1)                                                 sectionid (int) Return only this section                                                 sectionnumber (int) Return only this section with number (order)                                                 cmid (int) Return only this module information (among the whole sections structure)                                                 modname (string) Return only modules with this name \"label, forum, etc...\"                                                 modid (int) Return only the module with this id (to be used with modname")
    value: Optional[StrictStr] = Field(description="the value of the option,                                                                     this param is personaly validated in the external function.")
    __properties: ClassVar[List[str]] = ["name", "value"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCourseGetContentsParametersOptionsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if value (nullable) is None
        # and model_fields_set contains the field
        if self.value is None and "value" in self.model_fields_set:
            _dict['value'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCourseGetContentsParametersOptionsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCourseGetContentsParametersOptionsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "name": obj.get("name"),
            "value": obj.get("value")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.2 (Build: 20250811)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_contents_inner_tags_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_mini.configuration import settings

class CoreCourseGetContentsResponseInnerModulesInnerContentsInner(BaseModel):
    """
    CoreCourseGetContentsResponseInnerModulesInnerContentsInner
    """ # noqa: E501
    author: Optional[StrictStr] = Field(description="Content owner")
    content: Optional[StrictStr] = Field(default=None, description="Raw content, will be used when type is content")
    filename: Optional[StrictStr] = Field(description="filename")
    filepath: Optional[StrictStr] = Field(description="filepath")
    filesize: Optional[StrictInt] = Field(description="filesize")
    fileurl: Optional[StrictStr] = Field(default=None, description="downloadable file url")
    isexternalfile: Optional[StrictBool] = Field(default=None, description="Whether is an external file.")
    license: Optional[StrictStr] = Field(description="Content license")
    mimetype: Optional[StrictStr] = Field(default=None, description="File mime type.")
    repositorytype: Optional[StrictStr] = Field(default=None, description="The repository type for external files.")
    sortorder: Optional[StrictInt] = Field(description="Content sort order")
    tags: Optional[List[CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner]] = Field(default=None, description="Tags")
    timecreated: Optional[StrictInt] = Field(description="Time created")
    timemodified: Optional[StrictInt] = Field(description="Time modified")
    type: Optional[StrictStr] = Field(description="a file or a folder or external link")
    userid: Optional[StrictInt] = Field(description="User who added this content to moodle")
    __properties: ClassVar[List[str]] = ["author", "content", "filename", "filepath", "filesize", "fileurl", "isexternalfile", "license", "mimetype", "repositorytype", "sortorder", "tags", "timecreated", "timemodified", "type", "userid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCourseGetContentsResponseInnerModulesInnerContentsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # set to None if author (nullable) is None
        # and model_fields_set contains the field
        if self.author is None and "author" in self.model_fields_set:
            _dict['author'] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict['content'] = None

        # set to None if filename (nullable) is None
        # and model_fields_set contains the field
        if self.filename is None and "filename" in self.model_fields_set:
            _dict['filename'] = None

        # set to None if filepath (nullable) is None
        # and model_fields_set contains the field
        if self.filepath is None and "filepath" in self.model_fields_set:
            _dict['filepath'] = None

        # set to None if filesize (nullable) is None
        # and model_fields_set contains the field
        if self.filesize is None and "filesize" in self.model_fields_set:
            _dict['filesize'] = None

        # set to None if fileurl (nullable) is None
        # and model_fields_set contains the field
        if self.fileurl is None and "fileurl" in self.model_fields_set:
            _dict['fileurl'] = None

        # set to None if isexternalfile (nullable) is None
        # and model_fields_set contains the field
        if self.isexternalfile is None and "isexternalfile" in self.model_fields_set:
            _dict['isexternalfile'] = None

        # set to None if license (nullable) is None
        # and model_fields_set contains the field
        if self.license is None and "license" in self.model_fields_set:
            _dict['license'] = None

        # set to None if mimetype (nullable) is None
        # and model_fields_set contains the field
        if self.mimetype is None and "mimetype" in self.model_fields_set:
            _dict['mimetype'] = None

        # set to None if repositorytype (nullable) is None
        # and model_fields_set contains the field
        if self.repositorytype is None and "repositorytype" in self.model_fields_set:
            _dict['repositorytype'] = None

        # set to None if sortorder (nullable) is None
        # and model_fields_set contains the field
        if self.sortorder is None and "sortorder" in self.model_fields_set:
            _dict['sortorder'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if type (nullable) is None
        # and model_fields_set contains the field
        if self.type is None and "type" in self.model_fields_set:
            _dict['type'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCourseGetContentsResponseInnerModulesInnerContentsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCourseGetContentsResponseInnerModulesInnerContentsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "author": obj.get("author"),
            "content": obj.get("content"),
            "filename": obj.get("filename"),
            "filepath": obj.get("filepath"),
            "filesize": obj.get("filesize"),
            "fileurl": obj.get("fileurl"),
            "isexternalfile": obj.get("isexternalfile"),
            "license": obj.get("license"),
            "mimetype": obj.get("mimetype"),
            "repositorytype": obj.get("repositorytype"),
            "sortorder": obj.get("sortorder"),
            "tags": [CoreCourseGetContentsResponseInnerModulesInnerContentsInnerTagsInner.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "timecreated": obj.get("timecreated"),
            "timemodified": obj.get("timemodified"),
            "type": obj.get("type"),
            "userid": obj.get("userid")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.2 (Build: 20250811)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_mini.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_mini.configuration import settings

class CoreCourseGetContentsResponseInnerModulesInnerCompletiondata(BaseModel):
    """
    CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
    """ # noqa: E501
    details: List[CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner] = Field(description="An array of completion details containing the description and status.")
    hascompletion: StrictBool = Field(description="Whether this activity module has completion enabled.")
    isautomatic: StrictBool = Field(description="Whether this activity module instance tracks completion automatically.")
    isoverallcomplete: Optional[StrictBool] = Field(default=False, description="Whether the overall completion state of this course module should be marked as complete or not.")
    istrackeduser: StrictBool = Field(description="Checks whether completion is being tracked for this user.")
    overrideby: Optional[StrictInt] = Field(description="user ID that has overridden the completion state of this activity for the user.")
    state: StrictInt = Field(description="overall completion state of this course module.")
    timecompleted: StrictInt = Field(description="course completion timestamp.")
    uservisible: StrictBool = Field(description="Whether this activity is visible to user.")
    valueused: StrictBool = Field(description="True if module is used in a condition, false otherwise.")
    __properties: ClassVar[List[str]] = ["details", "hascompletion", "isautomatic", "isoverallcomplete", "istrackeduser", "overrideby", "state", "timecompleted", "uservisible", "valueused"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCourseGetContentsResponseInnerModulesInnerCompletiondata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in details (list)
        _items = []
        if self.details:
            for _item_details in self.details:
                if _item_details:
                    _items.append(_item_details.to_dict())
            _dict['details'] = _items
        # set to None if overrideby (nullable) is None
        # and model_fields_set contains the field
        if self.overrideby is None and "overrideby" in self.model_fields_set:
            _dict['overrideby'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCourseGetContentsResponseInnerModulesInnerCompletiondata from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCourseGetContentsResponseInnerModulesInnerCompletiondata" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "details": [CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner.from_dict(_item) for _item in obj["details"]] if obj.get("details") is not None else None,
            "hascompletion": obj.get("hascompletion") if obj.get("hascompletion") is not None else False,
            "isautomatic": obj.get("isautomatic") if obj.get("isautomatic") is not None else False,
            "isoverallcomplete": obj.get("isoverallcomplete") if obj.get("isoverallcomplete") is not None else False,
            "istrackeduser": obj.get("istrackeduser") if obj.get("istrackeduser") is not None else False,
            "overrideby": obj.get("overrideby"),
            "state": obj.get("state") if obj.get("state") is not None else 0,
            "timecompleted": obj.get("timecompleted") if obj.get("timecompleted") is not None else 0,
            "uservisible": obj.get("uservisible") if obj.get("uservisible") is not None else False,
            "valueused": obj.get("valueused") if obj.get("valueused") is not None else False
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj


